--- title: "wallaroo.model_version" type: docs linkTitle: "wallaroo.model_version" ---
class ModelVersion(wallaroo.object.Object):

The Wallaroo ModelVersion object. Each ModelVersion is a specific version of a Model.

ModelVersion( client: Optional[wallaroo.client.Client], data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

@staticmethod
def as_standalone( name: str, version: str, file_name: str) -> wallaroo.model_version.ModelVersion:

Creates a Model intended for use in generating standalone configurations

def id(self) -> int:
def uid(self) -> str:
def name(*args, **kwargs):
def version(*args, **kwargs):
def models_pk_id(*args, **kwargs):
def sha(*args, **kwargs):
def status(*args, **kwargs):
def file_name(*args, **kwargs):
def image_path(*args, **kwargs):
def last_update_time(*args, **kwargs):
inputs
outputs
def tags(*args, **kwargs):
def rehydrate_config(*args, **kwargs):
def config(self) -> wallaroo.model_config.ModelConfig:
def configure( self, runtime: Optional[str] = None, tensor_fields: Optional[List[str]] = None, filter_threshold: Optional[float] = None, input_schema: Optional[pyarrow.lib.Schema] = None, output_schema: Optional[pyarrow.lib.Schema] = None, batch_config: Optional[str] = None) -> wallaroo.model_version.ModelVersion:
def logs( self, limit: int = 100, valid: Optional[bool] = None, arrow: Optional[bool] = False) -> Tuple[Any, Optional[str]]:
def deploy( self, pipeline_name: str, deployment_config: Optional[wallaroo.deployment_config.DeploymentConfig] = None) -> wallaroo.pipeline.Pipeline:

Convenience function to quickly deploy a Model. It will configure the model, create a pipeline with a single model step, deploy it, and return the pipeline.

Typically, the configure() method is used to configure a model prior to deploying it. However, if a default configuration is sufficient, this function can be used to quickly deploy with said default configuration.

The filename this Model was generated from needs to have a recognizable file extension so that the runtime can be inferred. Currently, this is:

- `.onnx` -> ONNX runtime

###### Parameters

- str deployment_name: Name of the deployment to create. Must be unique across all deployments. Deployment names must be ASCII alpha-numeric characters plus dash (-) only.

class ModelVersionList(typing.List[wallaroo.model_version.ModelVersion]):

Wraps a list of model versions for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort